@@ -1,8 +1,16 @@
+import pytest
+import sys
+
 import pyqtgraph as pg
 
 pg.mkQApp()
 
-
+@pytest.mark.skipif(
+    sys.platform.startswith("linux")
+    and pg.Qt.QT_LIB == "PySide6"
+    and pg.Qt.PySide6.__version_info__ > (6, 0),
+    reason="taking gui thread causes segfault"
+)
 def test_nested_busy_cursors_clear_after_all_exit():
     with pg.BusyCursor():
         wait_cursor = pg.Qt.QtCore.Qt.CursorShape.WaitCursor
